@@ -1,5 +1,5 @@
 #include <Rconfig.h>
-#ifdef SUPPORT_OPENMP
+#ifdef _OPENMP
 #include <omp.h>
 #endif
 
@@ -7,7 +7,7 @@
  * - does nothing on platforms which don't support OpenMP
  */
 void omp_set_num_threads_ptr(int *np) {
-#ifdef SUPPORT_OPENMP
+#ifdef _OPENMP
   omp_set_num_threads(*np);
 #endif
 }
